#
# spec file for package ghc-pandoc-citeproc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name pandoc-citeproc
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.14.8.1
Release:        1.12
Summary:        Supports using pandoc with citeproc
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-pretty-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hs-bibutils-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-old-locale-devel
BuildRequires:  ghc-pandoc-devel
BuildRequires:  ghc-pandoc-types-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rfc5051-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-setenv-devel
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-tagsoup-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-xml-conduit-devel
BuildRequires:  ghc-yaml-devel
%if %{with tests}
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-temporary-devel
%endif

%description
The pandoc-citeproc library exports functions for using the citeproc system
with pandoc. It relies on citeproc-hs, a library for rendering bibliographic
reference citations into a variety of styles using a macro language called
Citation Style Language (CSL). More details on CSL can be found here:
<http://citationstyles.org/>.

Currently this package includes a heavily revised copy of the citeproc-hs code.
When citeproc-hs is updated to be compatible, this package will simply depend
on citeproc-hs.

This package also contains an executable: pandoc-citeproc, which works as a
pandoc filter, and also has a mode for converting bibliographic databases a
YAML format suitable for inclusion in pandoc YAML metadata.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/%{pkg_name}
%dir %{_datadir}/%{pkg_name}-%{version}
%dir %{_datadir}/%{pkg_name}-%{version}/locales
%dir %{_datadir}/%{pkg_name}-%{version}/man
%dir %{_datadir}/%{pkg_name}-%{version}/man/man1
%{_datadir}/%{pkg_name}-%{version}/LICENSE
%{_datadir}/%{pkg_name}-%{version}/README.md
%{_datadir}/%{pkg_name}-%{version}/changelog
%{_datadir}/%{pkg_name}-%{version}/chicago-author-date.csl
%{_datadir}/%{pkg_name}-%{version}/locales/*.xml
%{_datadir}/%{pkg_name}-%{version}/man/man1/pandoc-citeproc.1

%files devel -f %{name}-devel.files

%{_mandir}/man1/pandoc-citeproc.1%{?ext_man}

%changelog
* Mon Nov 19 2018 psimons@suse.com
- Update pandoc-citeproc to version 0.14.8.1.
  pandoc-citeproc (0.14.8.1)
  * Avoid putting a space after nonbreaking space at end of prefix.
    Previously this resulted in overly long spaces after abbreviations
    like 'cf.' at the end of prefixes.
  * Fix bug which caused names with apostrophes to be treated like
    East Asian names in certain styles (#360).
* Mon Oct 22 2018 psimons@suse.com
- Update pandoc-citeproc to version 0.14.8.
  pandoc-citeproc (0.14.8)
  * Add disambiguation to undated references (n.d.a, n.d.b) (#325).
  pandoc-citeproc (0.14.7)
  * Support first-reference-note-number (#31).
  pandoc-citeproc (0.14.6)
  * Bibtex: Support jstor and pubmed as eprinttype.
  * Bibtex: Resolve aliases on field names (#348).
    'primaryclass' -> 'eprintclass', 'archiveprefix' -> 'eprinttype'
  * Util: Rename betterThan to orIfNull.
  * Update chicago-author-date.csl and locale.
  * Don't apply sort-separator between non-byzantine names (#327).
    “As is the case for name-as-sort-order, this attribute [sort-separator]
    only affects names written in the latin or Cyrillic alphabets.”
  * Match zotero's regex for isByzantine.
    Fix issue #338 tests.
  * Explicitly use Text.XML.def in Parser.hs. (Eduard Nicodei, #331).
  * Ensure that groups with only empty variables are skipped (#338).
  * Make sure substitute works in nested contexts (#351).
    Previously it only worked for names elements right
    below it, not for names embedded in a conditional.
  * Handle date-part of the form `[[]]` or `[ null ]`.
    These seem to occur in the wild, and it seems better to parse them
    as an empty date parts than to crash with a parse error.
    See greenelab/manubot#66.
  * Allow pandoc 2.4.x.
* Mon Oct  1 2018 psimons@suse.com
- Update pandoc-citeproc to version 0.14.5.
  pandoc-citeproc (0.14.5)
  * Add flag to silence all warnings (#350, Albert Krewinkel).
    Introduce new command line flag `--quiet`/`-q` which can be used to
    suppress all warnings.
  * Use HTTPS for PMID and PMCID hyperlinks (#349, Daniel Himmelstein.)
  * Fix pattern match in do block that could fail, so pandoc-citeproc
    compiles with ghc 8.6.
  pandoc-citeproc (0.14.4)
  * Allow latest aeson (Adam Bergmark, #336).
  * Use latest hs-bibutils.
  * NBIB support (#333, Václav Haisman, API change).
  * Allow pandoc 2.3.x.
  * Update tests for pandoc changes.
  * Use recent yaml library that doesn't quote number ranges.
    This required some adjustments in the tests.
  * Use lts-12 for stack build.
  * Use Yaml.decodeEither' instead of deprecated decodeEither.
* Tue Jul 10 2018 psimons@suse.com
- Add pandoc-citeproc at version 0.14.3.1.
